arrc.models.embeddings.cnn\_wavenet
===================================

.. automodule:: arrc.models.embeddings.cnn_wavenet

   
   .. rubric:: Functions

   .. autosummary::
   
      build_cnn_wavenet_with_attentionpooling_model
      build_cnn_wavenet_with_globalpooling_model
   